componenttools.list_badly_formed_components_in_expr
===================================================

.. autofunction:: abjad.tools.componenttools.list_badly_formed_components_in_expr.list_badly_formed_components_in_expr
